=== modified file 'breezy/_rio_py.py'
--- breezy/_rio_py.py	2017-05-22 00:56:52 +0000
+++ breezy/_rio_py.py	2017-06-10 01:57:00 +0000
@@ -34,7 +34,7 @@
 def _read_stanza_utf8(line_iter):
     def iter_unicode_lines():
         for line in line_iter:
-            if not isinstance(line, str):
+            if not isinstance(line, bytes):
                 raise TypeError(line)
             yield line.decode('utf-8')
     return _read_stanza_unicode(iter_unicode_lines())

=== modified file 'breezy/btree_index.py'
--- breezy/btree_index.py	2017-06-05 20:48:31 +0000
+++ breezy/btree_index.py	2017-06-10 01:57:00 +0000
@@ -50,11 +50,11 @@
     )
 
 
-_BTSIGNATURE = "B+Tree Graph Index 2\n"
-_OPTION_ROW_LENGTHS = "row_lengths="
-_LEAF_FLAG = "type=leaf\n"
-_INTERNAL_FLAG = "type=internal\n"
-_INTERNAL_OFFSET = "offset="
+_BTSIGNATURE = b"B+Tree Graph Index 2\n"
+_OPTION_ROW_LENGTHS = b"row_lengths="
+_LEAF_FLAG = b"type=leaf\n"
+_INTERNAL_FLAG = b"type=internal\n"
+_INTERNAL_OFFSET = b"offset="
 
 _RESERVED_HEADER_BYTES = 120
 _PAGE_SIZE = 4096
@@ -406,11 +406,12 @@
             pad = (not isinstance(row, _LeafBuilderRow))
             row.finish_node(pad=pad)
         lines = [_BTSIGNATURE]
-        lines.append(_OPTION_NODE_REFS + str(self.reference_lists) + '\n')
-        lines.append(_OPTION_KEY_ELEMENTS + str(self._key_length) + '\n')
-        lines.append(_OPTION_LEN + str(key_count) + '\n')
+        lines.append(b'%s%d\n' % (_OPTION_NODE_REFS, self.reference_lists))
+        lines.append(b'%s%d\n' % (_OPTION_KEY_ELEMENTS, self._key_length))
+        lines.append(b'%s%d\n' % (_OPTION_LEN, key_count))
         row_lengths = [row.nodes for row in rows]
-        lines.append(_OPTION_ROW_LENGTHS + ','.join(map(str, row_lengths)) + '\n')
+        lines.append(_OPTION_ROW_LENGTHS + b','.join(
+            map(bytes, row_lengths)) + b'\n')
         if row_lengths and row_lengths[-1] > 1:
             result = tempfile.NamedTemporaryFile(prefix='bzr-index-')
         else:
@@ -1434,7 +1435,7 @@
             raise errors.BadIndexOptions(self)
         try:
             self._row_lengths = [int(length) for length in
-                options_line[len(_OPTION_ROW_LENGTHS):].split(',')
+                options_line[len(_OPTION_ROW_LENGTHS):].split(b',')
                 if length]
         except ValueError:
             raise errors.BadIndexOptions(self)

=== modified file 'breezy/bzrbranch.py'
--- breezy/bzrbranch.py	2017-06-05 22:01:28 +0000
+++ breezy/bzrbranch.py	2017-06-10 01:57:00 +0000
@@ -370,7 +370,7 @@
 
     def _read_last_revision_info(self):
         revision_string = self._transport.get_bytes('last-revision')
-        revno, revision_id = revision_string.rstrip('\n').split(' ', 1)
+        revno, revision_id = revision_string.rstrip(b'\n').split(b' ', 1)
         revision_id = cache_utf8.get_cached_utf8(revision_id)
         revno = int(revno)
         return revno, revision_id
@@ -670,9 +670,11 @@
             raise errors.NotBranchError(path=name, bzrdir=controldir)
         try:
             format_string = transport.get_bytes("format")
+            # GZ 2017-06-09: Where should format strings get decoded...
+            format_text = format_string.decode("ascii")
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base, bzrdir=controldir)
-        return klass._find_format(format_registry, 'branch', format_string)
+        return klass._find_format(format_registry, 'branch', format_text)
 
     def _branch_class(self):
         """What class to instantiate on open calls."""
@@ -680,11 +682,11 @@
 
     def _get_initial_config(self, append_revisions_only=None):
         if append_revisions_only:
-            return "append_revisions_only = True\n"
+            return b"append_revisions_only = True\n"
         else:
             # Avoid writing anything if append_revisions_only is disabled,
             # as that is the default.
-            return ""
+            return b""
 
     def _initialize_helper(self, a_bzrdir, utf8_files, name=None,
                            repository=None):
@@ -856,10 +858,10 @@
     def initialize(self, a_bzrdir, name=None, repository=None,
                    append_revisions_only=None):
         """Create a branch of this format in a_bzrdir."""
-        utf8_files = [('last-revision', '0 null:\n'),
+        utf8_files = [('last-revision', b'0 null:\n'),
                       ('branch.conf',
                           self._get_initial_config(append_revisions_only)),
-                      ('tags', ''),
+                      ('tags', b''),
                       ]
         return self._initialize_helper(a_bzrdir, utf8_files, name, repository)
 

=== modified file 'breezy/bzrdir.py'
--- breezy/bzrdir.py	2017-06-07 00:28:00 +0000
+++ breezy/bzrdir.py	2017-06-10 01:57:00 +0000
@@ -1180,7 +1180,8 @@
         lines = [self.get_format_string()]
         lines.extend([("%s %s\n" % (item[1], item[0])) for item in
             self.features.items()])
-        return "".join(lines)
+        # GZ 2016-07-09: Should push byte-ness up a level perhaps?
+        return "".join(lines).encode('ascii')
 
     @classmethod
     def _find_format(klass, registry, kind, format_string):
@@ -1231,17 +1232,19 @@
         """Return the .bzrdir style format present in a directory."""
         try:
             format_string = transport.get_bytes(".bzr/branch-format")
+            # GZ 2017-06-09: Where should format strings get decoded...
+            format_text = format_string.decode("ascii")
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
         try:
-            first_line = format_string[:format_string.index("\n")+1]
+            first_line = format_text[:format_text.index("\n")+1]
         except ValueError:
-            first_line = format_string
+            first_line = format_text
         try:
             cls = klass.formats.get(first_line)
         except KeyError:
             raise errors.UnknownFormatError(format=first_line, kind='bzrdir')
-        return cls.from_string(format_string)
+        return cls.from_string(format_text)
 
     @classmethod
     def known_formats(cls):
@@ -1447,9 +1450,9 @@
         del temp_control
         bzrdir_transport = transport.clone('.bzr')
         utf8_files = [('README',
-                       "This is a Bazaar control directory.\n"
-                       "Do not change any files in this directory.\n"
-                       "See http://bazaar.canonical.com/ for more information about Bazaar.\n"),
+                       b"This is a Bazaar control directory.\n"
+                       b"Do not change any files in this directory.\n"
+                       b"See http://bazaar.canonical.com/ for more information about Bazaar.\n"),
                       ('branch-format', self.as_string()),
                       ]
         # NB: no need to escape relative paths that are url safe.

=== modified file 'breezy/bzrrepository.py'
--- breezy/bzrrepository.py	2017-06-06 00:23:22 +0000
+++ breezy/bzrrepository.py	2017-06-10 01:57:00 +0000
@@ -132,7 +132,7 @@
         control_files.lock_write()
         transport = control_files._transport
         if shared == True:
-            utf8_files += [('shared-storage', '')]
+            utf8_files += [('shared-storage', b'')]
         try:
             transport.mkdir_multi(dirs, mode=a_bzrdir._get_dir_mode())
             for (filename, content_stream) in files:
@@ -155,9 +155,11 @@
         try:
             transport = a_bzrdir.get_repository_transport(None)
             format_string = transport.get_bytes("format")
+            # GZ 2017-06-17: Where should format strings get decoded...
+            format_text = format_string.decode("ascii")
         except errors.NoSuchFile:
             raise errors.NoRepositoryPresent(a_bzrdir)
-        return klass._find_format(format_registry, 'repository', format_string)
+        return klass._find_format(format_registry, 'repository', format_text)
 
     def check_support_status(self, allow_unsupported, recommend_upgrade=True,
             basedir=None):

=== modified file 'breezy/bzrworkingtree.py'
--- breezy/bzrworkingtree.py	2017-06-07 02:16:03 +0000
+++ breezy/bzrworkingtree.py	2017-06-10 01:57:00 +0000
@@ -651,7 +651,7 @@
 
     def _put_rio(self, filename, stanzas, header):
         self._must_be_locked()
-        my_file = _mod_rio.rio_file(stanzas, header)
+        my_file = _mod_rio.rio_file(stanzas, header.encode('ascii'))
         self._transport.put_file(filename, my_file,
             mode=self.bzrdir._get_file_mode())
 
@@ -1422,7 +1422,8 @@
         """Return format name for the working tree object in controldir."""
         try:
             transport = controldir.get_workingtree_transport(None)
-            return transport.get_bytes("format")
+            # GZ 2017-06-09: When do decode format strings?
+            return transport.get_bytes("format").decode('ascii')
         except errors.NoSuchFile:
             raise errors.NoWorkingTree(base=transport.base)
 

=== modified file 'breezy/config.py'
--- breezy/config.py	2017-06-05 20:48:31 +0000
+++ breezy/config.py	2017-06-10 01:57:00 +0000
@@ -114,6 +114,7 @@
 from .sixish import (
     binary_type,
     BytesIO,
+    PY3,
     text_type,
     string_types,
     )
@@ -476,10 +477,10 @@
         If no username can be found, errors.NoWhoami exception is raised.
         """
         v = os.environ.get('BRZ_EMAIL')
-        if v:
+        if v and not PY3:
             return v.decode(osutils.get_user_encoding())
         v = self._get_user_id()
-        if v:
+        if v and not PY3:
             return v
         return default_email()
 
@@ -1496,10 +1497,10 @@
 
 def default_email():
     v = os.environ.get('BRZ_EMAIL')
-    if v:
+    if v and not PY3:
         return v.decode(osutils.get_user_encoding())
     v = os.environ.get('EMAIL')
-    if v:
+    if v and not PY3:
         return v.decode(osutils.get_user_encoding())
     name, email = _auto_user_id()
     if name and email:
@@ -3264,7 +3265,8 @@
         # The following will do in the interim but maybe we don't want to
         # expose a path here but rather a config ID and its associated
         # object </hand wawe>.
-        return urlutils.join(self.transport.external_url(), self.file_name.encode("ascii"))
+        return urlutils.join(
+            self.transport.external_url(), urlutils.escape(self.file_name))
 
 
 # Note that LockableConfigObjStore inherits from ConfigObjStore because we need
@@ -3780,7 +3782,7 @@
             global _shared_stores_at_exit_installed
             stores = _shared_stores
             def save_config_changes():
-                for k, store in stores.iteritems():
+                for k, store in stores.items():
                     store.save_changes()
             if not _shared_stores_at_exit_installed:
                 # FIXME: Ugly hack waiting for library_state to always be

=== modified file 'breezy/generate_ids.py'
--- breezy/generate_ids.py	2017-05-22 00:56:52 +0000
+++ breezy/generate_ids.py	2017-06-10 01:57:00 +0000
@@ -59,10 +59,11 @@
     #           suffix forever.
     global _gen_file_id_suffix, _gen_file_id_serial
     if _gen_file_id_suffix is None:
-        _gen_file_id_suffix = "-%s-%s-" % (osutils.compact_date(time.time()),
-                                           osutils.rand_chars(16))
+        _gen_file_id_suffix =  ("-%s-%s-" % (
+                osutils.compact_date(time.time()), osutils.rand_chars(16))
+            ).encode("ascii")
     _gen_file_id_serial += 1
-    return _gen_file_id_suffix + str(_gen_file_id_serial)
+    return b"%s%d" % (_gen_file_id_suffix, _gen_file_id_serial)
 
 
 def gen_file_id(name):
@@ -81,8 +82,8 @@
     #    filesystems
     # 4) Removing starting '.' characters to prevent the file ids from
     #    being considered hidden.
-    ascii_word_only = str(_file_id_chars_re.sub('', name.lower()))
-    short_no_dots = ascii_word_only.lstrip('.')[:20]
+    ascii_word_only = _file_id_chars_re.sub('', name.lower()).encode('ascii')
+    short_no_dots = ascii_word_only.lstrip(b'.')[:20]
     return short_no_dots + _next_id_suffix()
 
 

=== modified file 'breezy/index.py'
--- breezy/index.py	2017-06-05 20:48:31 +0000
+++ breezy/index.py	2017-06-10 01:57:00 +0000
@@ -50,10 +50,10 @@
 from .static_tuple import StaticTuple
 
 _HEADER_READV = (0, 200)
-_OPTION_KEY_ELEMENTS = "key_elements="
-_OPTION_LEN = "len="
-_OPTION_NODE_REFS = "node_ref_lists="
-_SIGNATURE = "Bazaar Graph Index 1\n"
+_OPTION_KEY_ELEMENTS = b"key_elements="
+_OPTION_LEN = b"len="
+_OPTION_NODE_REFS = b"node_ref_lists="
+_SIGNATURE = b"Bazaar Graph Index 1\n"
 
 
 _whitespace_re = re.compile('[\t\n\x0b\x0c\r\x00 ]')
@@ -257,10 +257,10 @@
         should be written to disk.
         """
         lines = [_SIGNATURE]
-        lines.append(_OPTION_NODE_REFS + str(self.reference_lists) + '\n')
-        lines.append(_OPTION_KEY_ELEMENTS + str(self._key_length) + '\n')
+        lines.append(b'%s%d\n' % (_OPTION_NODE_REFS, self.reference_lists))
+        lines.append(b'%s%d\n' % (_OPTION_KEY_ELEMENTS, self._key_length))
         key_count = len(self._nodes) - len(self._absent_keys)
-        lines.append(_OPTION_LEN + str(key_count) + '\n')
+        lines.append(b'%s%d\n' % (_OPTION_LEN, key_count))
         prefix_length = sum(len(x) for x in lines)
         # references are byte offsets. To avoid having to do nasty
         # polynomial work to resolve offsets (references to later in the
@@ -323,19 +323,19 @@
             for key, non_ref_bytes, total_references in key_offset_info:
                 key_addresses[key] = non_ref_bytes + total_references*digits
             # serialise
-            format_string = '%%0%sd' % digits
+            format_string = b'%%0%dd' % digits
         for key, (absent, references, value) in nodes:
             flattened_references = []
             for ref_list in references:
                 ref_addresses = []
                 for reference in ref_list:
                     ref_addresses.append(format_string % key_addresses[reference])
-                flattened_references.append('\r'.join(ref_addresses))
-            string_key = '\x00'.join(key)
-            lines.append("%s\x00%s\x00%s\x00%s\n" % (string_key, absent,
-                '\t'.join(flattened_references), value))
-        lines.append('\n')
-        result = BytesIO(''.join(lines))
+                flattened_references.append(b'\r'.join(ref_addresses))
+            string_key = b'\x00'.join(key)
+            lines.append(b"%s\x00%s\x00%s\x00%s\n" % (string_key, absent,
+                b'\t'.join(flattened_references), value))
+        lines.append(b'\n')
+        result = BytesIO(b''.join(lines))
         if expected_bytes and len(result.getvalue()) != expected_bytes:
             raise errors.BzrError('Failed index creation. Internal error:'
                 ' mismatched output length and expected length: %d %d' %

=== modified file 'breezy/inventory.py'
--- breezy/inventory.py	2017-06-05 20:48:31 +0000
+++ breezy/inventory.py	2017-06-10 01:57:00 +0000
@@ -27,7 +27,7 @@
 
 # This should really be an id randomly assigned when the tree is
 # created, but it's not for now.
-ROOT_ID = "TREE_ROOT"
+ROOT_ID = b"TREE_ROOT"
 
 from .lazy_import import lazy_import
 lazy_import(globals(), """

=== modified file 'breezy/iterablefile.py'
--- breezy/iterablefile.py	2017-05-25 01:35:55 +0000
+++ breezy/iterablefile.py	2017-06-10 01:57:00 +0000
@@ -23,7 +23,7 @@
     def __init__(self, iterable):
         object.__init__(self)
         self._iter = iterable.__iter__()
-        self._buffer = ""
+        self._buffer = b""
         self.done = False
 
     def read_n(self, length):
@@ -70,7 +70,7 @@
                 result += next(self._iter)
             except StopIteration:
                 self.done = True
-                self._buffer = ""
+                self._buffer = b""
                 return result
         output_length = result_length(result)
         self._buffer = result[output_length:]
@@ -110,8 +110,8 @@
     def _make_iterator(self):
         while not self._file_base.done:
             self._check_closed()
-            result = self._file_base.read_to('\n')
-            if result != '':
+            result = self._file_base.read_to(b'\n')
+            if result != b'':
                 yield result
 
     def _check_closed(self):
@@ -227,7 +227,7 @@
         Traceback (most recent call last):
         ValueError: File is closed.
         """
-        return self.read_to('\n', size)
+        return self.read_to(b'\n', size)
 
     def readlines(self, sizehint=None):
         """
@@ -243,7 +243,7 @@
         lines = []
         while True:
             line = self.readline()
-            if line == "":
+            if line == b"":
                 return lines
             if sizehint is None:
                 lines.append(line)

=== modified file 'breezy/lockable_files.py'
--- breezy/lockable_files.py	2017-05-22 00:56:52 +0000
+++ breezy/lockable_files.py	2017-06-10 01:57:00 +0000
@@ -102,11 +102,9 @@
 
     def _escape(self, file_or_path):
         """DEPRECATED: Do not use outside this class"""
-        if not isinstance(file_or_path, basestring):
-            file_or_path = '/'.join(file_or_path)
         if file_or_path == '':
             return u''
-        return urlutils.escape(osutils.safe_unicode(file_or_path))
+        return urlutils.escape(file_or_path)
 
     def _find_modes(self):
         """Determine the appropriate modes for files and directories.
@@ -203,7 +201,8 @@
             try:
                 self._lock.unlock()
             finally:
-                self._lock_mode = self._lock_count = None
+                self._lock_count = 0
+                self._lock_mode = None
 
     def is_locked(self):
         """Return true if this LockableFiles group is locked"""

=== modified file 'breezy/osutils.py'
--- breezy/osutils.py	2017-06-05 23:54:45 +0000
+++ breezy/osutils.py	2017-06-10 01:57:00 +0000
@@ -349,6 +349,8 @@
 def _posix_getuser_unicode():
     """Get username from environment or password database as unicode"""
     name = getpass.getuser()
+    if PY3:
+        return name
     user_encoding = get_user_encoding()
     try:
         return name.decode(user_encoding)
@@ -994,7 +996,10 @@
     """
     s = ''
     for raw_byte in rand_bytes(num):
-        s += ALNUM[ord(raw_byte) % 36]
+        if not PY3:
+            s += ALNUM[ord(raw_byte) % 36]
+        else:
+            s += ALNUM[raw_byte % 36]
     return s
 
 
@@ -1106,8 +1111,9 @@
 
     This supports Unicode or plain string objects.
     """
-    lines = s.split('\n')
-    result = [line + '\n' for line in lines[:-1]]
+    nl = b'\n' if isinstance(s, bytes) else u'\n'
+    lines = s.split(nl)
+    result = [line + nl for line in lines[:-1]]
     if lines[-1]:
         result.append(lines[-1])
     return result
@@ -2038,6 +2044,8 @@
         return win32utils.get_host_name()
     else:
         import socket
+        if PY3:
+            return socket.gethostname()
         return socket.gethostname().decode(get_user_encoding())
 
 

=== modified file 'breezy/repofmt/pack_repo.py'
--- breezy/repofmt/pack_repo.py	2017-06-05 23:35:09 +0000
+++ breezy/repofmt/pack_repo.py	2017-06-10 01:57:00 +0000
@@ -1912,7 +1912,8 @@
         dirs = ['indices', 'obsolete_packs', 'packs', 'upload']
         builder = self.index_builder_class()
         files = [('pack-names', builder.finish())]
-        utf8_files = [('format', self.get_format_string())]
+        # GZ 2017-06-09: Where should format strings get decoded...
+        utf8_files = [('format', self.get_format_string().encode('ascii'))]
 
         self._upload_blank_content(a_bzrdir, dirs, files, utf8_files, shared)
         repository = self.open(a_bzrdir=a_bzrdir, _found=True)

=== modified file 'breezy/revision.py'
--- breezy/revision.py	2017-06-05 20:48:31 +0000
+++ breezy/revision.py	2017-06-10 01:57:00 +0000
@@ -29,8 +29,8 @@
     )
 from .osutils import contains_whitespace
 
-NULL_REVISION="null:"
-CURRENT_REVISION="current:"
+NULL_REVISION=b"null:"
+CURRENT_REVISION=b"current:"
 
 
 class Revision(object):

=== modified file 'breezy/rio.py'
--- breezy/rio.py	2017-05-22 00:56:52 +0000
+++ breezy/rio.py	2017-06-10 01:57:00 +0000
@@ -36,6 +36,9 @@
 
 from . import osutils
 from .iterablefile import IterableFile
+from .sixish import (
+    text_type,
+    )
 
 # XXX: some redundancy is allowing to write stanzas in isolation as well as
 # through a writer object.
@@ -74,11 +77,11 @@
     """Produce a rio IterableFile from an iterable of stanzas"""
     def str_iter():
         if header is not None:
-            yield header + '\n'
+            yield header + b'\n'
         first_stanza = True
         for s in stanzas:
             if first_stanza is not True:
-                yield '\n'
+                yield b'\n'
             for line in s.to_lines():
                 yield line
             first_stanza = False
@@ -121,12 +124,10 @@
         """Append a name and value to the stanza."""
         if not valid_tag(tag):
             raise ValueError("invalid tag %r" % (tag,))
-        if isinstance(value, str):
-            value = unicode(value)
-        elif isinstance(value, unicode):
+        if isinstance(value, bytes):
+            value = value.decode('ascii')
+        elif isinstance(value, text_type):
             pass
-        ## elif isinstance(value, (int, long)):
-        ##    value = str(value)           # XXX: python2.4 without L-suffix
         else:
             raise TypeError("invalid type for rio value: %r of type %s"
                             % (value, type(value)))
@@ -175,20 +176,20 @@
         result = []
         for tag, value in self.items:
             if value == '':
-                result.append(tag + ': \n')
+                result.append(tag.encode('ascii') + b': \n')
             elif '\n' in value:
                 # don't want splitlines behaviour on empty lines
                 val_lines = value.split('\n')
-                result.append(tag + ': ' + val_lines[0].encode('utf-8') + '\n')
+                result.append(tag + b': ' + val_lines[0].encode('utf-8') + b'\n')
                 for line in val_lines[1:]:
-                    result.append('\t' + line.encode('utf-8') + '\n')
+                    result.append(b'\t' + line.encode('utf-8') + b'\n')
             else:
-                result.append(tag + ': ' + value.encode('utf-8') + '\n')
+                result.append(tag.encode('ascii') + b': ' + value.encode('utf-8') + b'\n')
         return result
 
     def to_string(self):
         """Return stanza as a single string"""
-        return ''.join(self.to_lines())
+        return b''.join(self.to_lines())
 
     def to_unicode(self):
         """Return stanza as a single Unicode string.

=== modified file 'breezy/tests/__init__.py'
--- breezy/tests/__init__.py	2017-06-10 00:06:46 +0000
+++ breezy/tests/__init__.py	2017-06-10 01:57:00 +0000
@@ -90,6 +90,7 @@
     pass
 from ..sixish import (
     BytesIO,
+    PY3,
     string_types,
     text_type,
     )
@@ -110,7 +111,7 @@
 # Mark this python module as being part of the implementation
 # of unittest: this gives us better tracebacks where the last
 # shown frame is the test code, not our assertXYZ.
-__unittest = 1
+#__unittest = 1
 
 default_transport = test_server.LocalURLServer
 
@@ -1534,11 +1535,8 @@
     def assertFileEqual(self, content, path):
         """Fail if path does not contain 'content'."""
         self.assertPathExists(path)
-        f = file(path, 'rb')
-        try:
+        with open(path, 'rb') as f:
             s = f.read()
-        finally:
-            f.close()
         self.assertEqualDiff(content, s)
 
     def assertDocstring(self, expected_docstring, obj):
@@ -1551,7 +1549,7 @@
 
     def assertPathExists(self, path):
         """Fail unless path or paths, which may be abs or relative, exist."""
-        if not isinstance(path, basestring):
+        if not isinstance(path, (str, text_type)):
             for p in path:
                 self.assertPathExists(p)
         else:
@@ -2661,7 +2659,7 @@
         """
         if format is None:
             format = self.get_default_format()
-        if isinstance(format, basestring):
+        if isinstance(format, str):
             format = controldir.format_registry.make_bzrdir(format)
         return format
 
@@ -2710,7 +2708,7 @@
 
     def overrideEnvironmentForTesting(self):
         test_home_dir = self.test_home_dir
-        if isinstance(test_home_dir, text_type):
+        if not PY3 and isinstance(test_home_dir, text_type):
             test_home_dir = test_home_dir.encode(sys.getfilesystemencoding())
         self.overrideEnv('HOME', test_home_dir)
         self.overrideEnv('BRZ_HOME', test_home_dir)
@@ -2769,11 +2767,8 @@
 
     def check_file_contents(self, filename, expect):
         self.log("check contents of file %s" % filename)
-        f = file(filename)
-        try:
+        with open(filename) as f:
             contents = f.read()
-        finally:
-            f.close()
         if contents != expect:
             self.log("expected: %r" % expect)
             self.log("actually: %r" % contents)
@@ -2820,11 +2815,8 @@
         os.mkdir(self.test_dir)
         os.chdir(self.test_dir)
         # put name of test inside
-        f = file(self.test_base_dir + '/name', 'w')
-        try:
+        with open(self.test_base_dir + '/name', 'w') as f:
             f.write(self.id())
-        finally:
-            f.close()
 
     def deleteTestDir(self):
         os.chdir(TestCaseWithMemoryTransport.TEST_ROOT)
@@ -4376,9 +4368,9 @@
     # except on win32, where rmtree(str) will fail
     # since it doesn't have the property of byte-stream paths
     # (they are either ascii or mbcs)
-    if sys.platform == 'win32':
+    if sys.platform == 'win32' and isinstance(dirname, bytes):
         # make sure we are using the unicode win32 api
-        dirname = text_type(dirname)
+        dirname = dirname.decode('mbcs')
     else:
         dirname = dirname.encode(sys.getfilesystemencoding())
     try:

=== modified file 'breezy/tests/treeshape.py'
--- breezy/tests/treeshape.py	2017-05-22 00:56:52 +0000
+++ breezy/tests/treeshape.py	2017-06-10 01:57:00 +0000
@@ -53,11 +53,8 @@
         elif name[-1] == '@':
             os.symlink(tt[1], tt[0][:-1])
         else:
-            f = file(name, 'wb')
-            try:
+            with open(name, 'wb') as f:
                 f.write(tt[1])
-            finally:
-                f.close()
 
 
 def capture_tree_contents(top):
@@ -75,7 +72,9 @@
             if stat.S_ISLNK(info.st_mode):
                 yield (fullpath + '@', os.readlink(fullpath))
             elif stat.S_ISREG(info.st_mode):
-                yield (fullpath, file(fullpath, 'rb').read())
+                with open(fullpath, 'rb') as f:
+                    file_bytes = f.read()
+                yield (fullpath, file_bytes)
             else:
                 warning("can't capture file %s with mode %#o",
                         fullpath, info.st_mode)

=== modified file 'breezy/transport/__init__.py'
--- breezy/transport/__init__.py	2017-06-08 00:00:28 +0000
+++ breezy/transport/__init__.py	2017-06-10 01:57:00 +0000
@@ -45,6 +45,7 @@
 
 from ..sixish import (
     BytesIO,
+    PY3,
     string_types,
     )
 from ..trace import (
@@ -127,7 +128,7 @@
                              register_netloc=False):
     transport_list_registry.register_transport(prefix, help)
     if register_netloc:
-        if not prefix.endswith(b'://'):
+        if not prefix.endswith('://'):
             raise ValueError(prefix)
         register_urlparse_netloc_protocol(prefix[:-3])
 
@@ -879,7 +880,7 @@
         :param mode: Create the file with the given mode.
         :return: None
         """
-        if not isinstance(raw_bytes, str):
+        if not isinstance(raw_bytes, bytes):
             raise TypeError(
                 'raw_bytes must be a plain string, not %s' % type(raw_bytes))
         return self.put_file(relpath, BytesIO(raw_bytes), mode=mode)
@@ -902,7 +903,7 @@
                         create it, and then try again.
         :param dir_mode: Possible access permissions for new directories.
         """
-        if not isinstance(raw_bytes, str):
+        if not isinstance(raw_bytes, bytes):
             raise TypeError(
                 'raw_bytes must be a plain string, not %s' % type(raw_bytes))
         self.put_file_non_atomic(relpath, BytesIO(raw_bytes), mode=mode,
@@ -991,22 +992,22 @@
         """
         raise NotImplementedError(self.append_file)
 
-    def append_bytes(self, relpath, bytes, mode=None):
+    def append_bytes(self, relpath, data, mode=None):
         """Append bytes to a file at relpath.
 
         The file is created if it does not already exist.
 
-        :type f: str
-        :param f: a string of the bytes to append.
+        :param relpath: The relative path to the file.
+        :param data: a string of the bytes to append.
         :param mode: Unix mode for newly created files.  This is not used for
             existing files.
 
         :returns: the length of relpath before the content was written to it.
         """
-        if not isinstance(bytes, str):
+        if not isinstance(data, bytes):
             raise TypeError(
-                'bytes must be a plain string, not %s' % type(bytes))
-        return self.append_file(relpath, BytesIO(bytes), mode=mode)
+                'bytes must be a plain string, not %s' % type(data))
+        return self.append_file(relpath, BytesIO(data), mode=mode)
 
     def append_multi(self, files, pb=None):
         """Append the text in each file-like or string object to
@@ -1593,6 +1594,8 @@
             raise errors.InvalidURL(path=location,
                 extra='URLs must be properly escaped')
         location = urlutils.local_path_to_url(location)
+    if PY3:
+        location = location.decode('ascii')
 
     if location.startswith("file:") and not location.startswith("file://"):
         return urlutils.join(urlutils.local_path_to_url("."), location[5:])
@@ -1733,130 +1736,130 @@
 
 
 # None is the default transport, for things with no url scheme
-register_transport_proto(b'file://',
+register_transport_proto('file://',
             help="Access using the standard filesystem (default)")
-register_lazy_transport(b'file://', 'breezy.transport.local', 'LocalTransport')
+register_lazy_transport('file://', 'breezy.transport.local', 'LocalTransport')
 
-register_transport_proto(b'sftp://',
+register_transport_proto('sftp://',
             help="Access using SFTP (most SSH servers provide SFTP).",
             register_netloc=True)
-register_lazy_transport(b'sftp://', 'breezy.transport.sftp', 'SFTPTransport')
+register_lazy_transport('sftp://', 'breezy.transport.sftp', 'SFTPTransport')
 # Decorated http transport
-register_transport_proto(b'http+urllib://',
+register_transport_proto('http+urllib://',
 #                help="Read-only access of branches exported on the web."
                          register_netloc=True)
-register_lazy_transport(b'http+urllib://', 'breezy.transport.http._urllib',
+register_lazy_transport('http+urllib://', 'breezy.transport.http._urllib',
                         'HttpTransport_urllib')
-register_transport_proto(b'https+urllib://',
+register_transport_proto('https+urllib://',
 #                help="Read-only access of branches exported on the web using SSL."
                          register_netloc=True)
-register_lazy_transport(b'https+urllib://', 'breezy.transport.http._urllib',
+register_lazy_transport('https+urllib://', 'breezy.transport.http._urllib',
                         'HttpTransport_urllib')
 # Default http transports (last declared wins (if it can be imported))
-register_transport_proto(b'http://',
+register_transport_proto('http://',
                  help="Read-only access of branches exported on the web.")
-register_transport_proto(b'https://',
+register_transport_proto('https://',
             help="Read-only access of branches exported on the web using SSL.")
 # The default http implementation is urllib
-register_lazy_transport(b'http://', 'breezy.transport.http._urllib',
+register_lazy_transport('http://', 'breezy.transport.http._urllib',
                         'HttpTransport_urllib')
-register_lazy_transport(b'https://', 'breezy.transport.http._urllib',
+register_lazy_transport('https://', 'breezy.transport.http._urllib',
                         'HttpTransport_urllib')
 
-register_transport_proto(b'ftp://', help="Access using passive FTP.")
-register_lazy_transport(b'ftp://', 'breezy.transport.ftp', 'FtpTransport')
-register_transport_proto(b'aftp://', help="Access using active FTP.")
-register_lazy_transport(b'aftp://', 'breezy.transport.ftp', 'FtpTransport')
-register_transport_proto(b'gio+', help="Access using any GIO supported protocols.")
-register_lazy_transport(b'gio+', 'breezy.transport.gio_transport', 'GioTransport')
+register_transport_proto('ftp://', help="Access using passive FTP.")
+register_lazy_transport('ftp://', 'breezy.transport.ftp', 'FtpTransport')
+register_transport_proto('aftp://', help="Access using active FTP.")
+register_lazy_transport('aftp://', 'breezy.transport.ftp', 'FtpTransport')
+register_transport_proto('gio+', help="Access using any GIO supported protocols.")
+register_lazy_transport('gio+', 'breezy.transport.gio_transport', 'GioTransport')
 
 
 # Default to trying GSSAPI authentication (if the kerberos module is
 # available)
-register_transport_proto(b'ftp+gssapi://', register_netloc=True)
-register_transport_proto(b'aftp+gssapi://', register_netloc=True)
-register_transport_proto(b'ftp+nogssapi://', register_netloc=True)
-register_transport_proto(b'aftp+nogssapi://', register_netloc=True)
-register_lazy_transport(b'ftp+gssapi://', 'breezy.transport.ftp._gssapi',
-                        'GSSAPIFtpTransport')
-register_lazy_transport(b'aftp+gssapi://', 'breezy.transport.ftp._gssapi',
-                        'GSSAPIFtpTransport')
-register_lazy_transport(b'ftp://', 'breezy.transport.ftp._gssapi',
-                        'GSSAPIFtpTransport')
-register_lazy_transport(b'aftp://', 'breezy.transport.ftp._gssapi',
-                        'GSSAPIFtpTransport')
-register_lazy_transport(b'ftp+nogssapi://', 'breezy.transport.ftp',
+register_transport_proto('ftp+gssapi://', register_netloc=True)
+register_transport_proto('aftp+gssapi://', register_netloc=True)
+register_transport_proto('ftp+nogssapi://', register_netloc=True)
+register_transport_proto('aftp+nogssapi://', register_netloc=True)
+register_lazy_transport('ftp+gssapi://', 'breezy.transport.ftp._gssapi',
+                        'GSSAPIFtpTransport')
+register_lazy_transport('aftp+gssapi://', 'breezy.transport.ftp._gssapi',
+                        'GSSAPIFtpTransport')
+register_lazy_transport('ftp://', 'breezy.transport.ftp._gssapi',
+                        'GSSAPIFtpTransport')
+register_lazy_transport('aftp://', 'breezy.transport.ftp._gssapi',
+                        'GSSAPIFtpTransport')
+register_lazy_transport('ftp+nogssapi://', 'breezy.transport.ftp',
                         'FtpTransport')
-register_lazy_transport(b'aftp+nogssapi://', 'breezy.transport.ftp',
+register_lazy_transport('aftp+nogssapi://', 'breezy.transport.ftp',
                         'FtpTransport')
 
-register_transport_proto(b'memory://')
-register_lazy_transport(b'memory://', 'breezy.transport.memory',
+register_transport_proto('memory://')
+register_lazy_transport('memory://', 'breezy.transport.memory',
                         'MemoryTransport')
 
-register_transport_proto(b'readonly+',
+register_transport_proto('readonly+',
 #              help="This modifier converts any transport to be readonly."
             )
-register_lazy_transport(b'readonly+', 'breezy.transport.readonly',
+register_lazy_transport('readonly+', 'breezy.transport.readonly',
                         'ReadonlyTransportDecorator')
 
-register_transport_proto(b'fakenfs+')
-register_lazy_transport(b'fakenfs+', 'breezy.transport.fakenfs',
+register_transport_proto('fakenfs+')
+register_lazy_transport('fakenfs+', 'breezy.transport.fakenfs',
                         'FakeNFSTransportDecorator')
 
-register_transport_proto(b'log+')
-register_lazy_transport(b'log+', 'breezy.transport.log', 'TransportLogDecorator')
+register_transport_proto('log+')
+register_lazy_transport('log+', 'breezy.transport.log', 'TransportLogDecorator')
 
-register_transport_proto(b'trace+')
-register_lazy_transport(b'trace+', 'breezy.transport.trace',
+register_transport_proto('trace+')
+register_lazy_transport('trace+', 'breezy.transport.trace',
                         'TransportTraceDecorator')
 
-register_transport_proto(b'unlistable+')
-register_lazy_transport(b'unlistable+', 'breezy.transport.unlistable',
+register_transport_proto('unlistable+')
+register_lazy_transport('unlistable+', 'breezy.transport.unlistable',
                         'UnlistableTransportDecorator')
 
-register_transport_proto(b'brokenrename+')
-register_lazy_transport(b'brokenrename+', 'breezy.transport.brokenrename',
+register_transport_proto('brokenrename+')
+register_lazy_transport('brokenrename+', 'breezy.transport.brokenrename',
                         'BrokenRenameTransportDecorator')
 
-register_transport_proto(b'vfat+')
-register_lazy_transport(b'vfat+',
+register_transport_proto('vfat+')
+register_lazy_transport('vfat+',
                         'breezy.transport.fakevfat',
                         'FakeVFATTransportDecorator')
 
-register_transport_proto(b'nosmart+')
-register_lazy_transport(b'nosmart+', 'breezy.transport.nosmart',
+register_transport_proto('nosmart+')
+register_lazy_transport('nosmart+', 'breezy.transport.nosmart',
                         'NoSmartTransportDecorator')
 
-register_transport_proto(b'bzr://',
+register_transport_proto('bzr://',
             help="Fast access using the Bazaar smart server.",
                          register_netloc=True)
 
-register_lazy_transport(b'bzr://', 'breezy.transport.remote',
+register_lazy_transport('bzr://', 'breezy.transport.remote',
                         'RemoteTCPTransport')
-register_transport_proto(b'bzr-v2://', register_netloc=True)
+register_transport_proto('bzr-v2://', register_netloc=True)
 
-register_lazy_transport(b'bzr-v2://', 'breezy.transport.remote',
+register_lazy_transport('bzr-v2://', 'breezy.transport.remote',
                         'RemoteTCPTransportV2Only')
-register_transport_proto(b'bzr+http://',
+register_transport_proto('bzr+http://',
 #                help="Fast access using the Bazaar smart server over HTTP."
                          register_netloc=True)
-register_lazy_transport(b'bzr+http://', 'breezy.transport.remote',
+register_lazy_transport('bzr+http://', 'breezy.transport.remote',
                         'RemoteHTTPTransport')
-register_transport_proto(b'bzr+https://',
+register_transport_proto('bzr+https://',
 #                help="Fast access using the Bazaar smart server over HTTPS."
                          register_netloc=True)
-register_lazy_transport(b'bzr+https://',
+register_lazy_transport('bzr+https://',
                         'breezy.transport.remote',
                         'RemoteHTTPTransport')
-register_transport_proto(b'bzr+ssh://',
+register_transport_proto('bzr+ssh://',
             help="Fast access using the Bazaar smart server over SSH.",
             register_netloc=True)
-register_lazy_transport(b'bzr+ssh://', 'breezy.transport.remote',
+register_lazy_transport('bzr+ssh://', 'breezy.transport.remote',
                         'RemoteSSHTransport')
 
-register_transport_proto(b'ssh:')
-register_lazy_transport(b'ssh:', 'breezy.transport.remote',
+register_transport_proto('ssh:')
+register_lazy_transport('ssh:', 'breezy.transport.remote',
                         'HintingSSHTransport')
 
 

=== modified file 'breezy/transport/local.py'
--- breezy/transport/local.py	2017-05-30 19:16:23 +0000
+++ breezy/transport/local.py	2017-06-10 01:57:00 +0000
@@ -50,15 +50,15 @@
 
     def __init__(self, base):
         """Set the base path where files will be stored."""
-        if not base.startswith(b'file://'):
+        if not base.startswith('file://'):
             raise AssertionError("not a file:// url: %r" % base)
-        if base[-1] != b'/':
-            base = base + b'/'
+        if base[-1] != '/':
+            base = base + '/'
 
         # Special case : windows has no "root", but does have
         # multiple lettered drives inside it. #240910
-        if sys.platform == 'win32' and base == b'file:///':
-            base = b''
+        if sys.platform == 'win32' and base == 'file:///':
+            base = ''
             self._local_base = ''
             super(LocalTransport, self).__init__(base)
             return
@@ -189,7 +189,7 @@
         :param relpath: Location to put the contents, relative to base.
         :param raw_bytes:   String
         """
-        if not isinstance(raw_bytes, str):
+        if not isinstance(raw_bytes, bytes):
             raise TypeError(
                 'raw_bytes must be a plain string, not %s' % type(raw_bytes))
         path = relpath

=== modified file 'breezy/urlutils.py'
--- breezy/urlutils.py	2017-06-05 20:48:31 +0000
+++ breezy/urlutils.py	2017-06-10 01:57:00 +0000
@@ -38,6 +38,7 @@
 """)
 
 from .sixish import (
+    PY3,
     text_type,
     )
 
@@ -73,16 +74,16 @@
 # urllib module because urllib unconditionally imports socket, which imports
 # ssl.
 
-always_safe = (b'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
-               b'abcdefghijklmnopqrstuvwxyz'
-               b'0123456789' b'_.-')
+always_safe = ('ABCDEFGHIJKLMNOPQRSTUVWXYZ'
+               'abcdefghijklmnopqrstuvwxyz'
+               '0123456789' '_.-')
 _safe_map = {}
-for i, c in zip(range(256), bytes(bytearray(range(256)))):
-    _safe_map[c] = c if (i < 128 and c in always_safe) else '%{0:02X}'.format(i).encode('ascii')
+for i, c in zip(range(256), ''.join(map(chr, range(256)))):
+    _safe_map[c] = c if (i < 128 and c in always_safe) else '%{0:02X}'.format(i)
 _safe_quoters = {}
 
 
-def quote(s, safe=b'/'):
+def quote(s, safe='/'):
     """quote('abc def') -> 'abc%20def'
 
     Each part of a URL, e.g. the path info, the query, etc., has a
@@ -119,35 +120,17 @@
         _safe_quoters[cachekey] = (quoter, safe)
     if not s.rstrip(safe):
         return s
-    return b''.join(map(quoter, s))
-
-
-_hexdig = '0123456789ABCDEFabcdef'
-_hextochr = dict((a + b, chr(int(a + b, 16)))
-                 for a in _hexdig for b in _hexdig)
-
-def unquote(s):
-    """unquote('abc%20def') -> 'abc def'."""
-    res = s.split(b'%')
-    # fastpath
-    if len(res) == 1:
-        return s
-    s = res[0]
-    for item in res[1:]:
-        try:
-            s += _hextochr[item[:2]] + item[2:]
-        except KeyError:
-            s += b'%' + item
-        except UnicodeDecodeError:
-            s += unichr(int(item[:2], 16)) + item[2:]
-    return s
+    return ''.join(map(quoter, s))
+
+
+unquote = urlparse.unquote
 
 
 def escape(relpath):
     """Escape relpath to be a valid url."""
-    if isinstance(relpath, text_type):
+    if not isinstance(relpath, str):
         relpath = relpath.encode('utf-8')
-    return quote(relpath, safe=b'/~')
+    return quote(relpath, safe='/~')
 
 
 def file_relpath(base, path):
@@ -179,7 +162,7 @@
 
     # Find the path separating slash
     # (first slash after the ://)
-    first_path_slash = path.find(b'/')
+    first_path_slash = path.find('/')
     if first_path_slash == -1:
         return len(scheme), None
     return len(scheme), first_path_slash+m.start('path')
@@ -236,41 +219,41 @@
     We really should try to have exactly one place in the code base responsible
     for combining paths of URLs.
     """
-    path = base.split(b'/')
-    if len(path) > 1 and path[-1] == b'':
+    path = base.split('/')
+    if len(path) > 1 and path[-1] == '':
         #If the path ends in a trailing /, remove it.
         path.pop()
     for arg in args:
-        if arg.startswith(b'/'):
+        if arg.startswith('/'):
             path = []
-        for chunk in arg.split(b'/'):
-            if chunk == b'.':
+        for chunk in arg.split('/'):
+            if chunk == '.':
                 continue
-            elif chunk == b'..':
-                if path == [b'']:
+            elif chunk == '..':
+                if path == ['']:
                     raise errors.InvalidURLJoin('Cannot go above root',
                             base, args)
                 path.pop()
             else:
                 path.append(chunk)
-    if path == [b'']:
-        return b'/'
+    if path == ['']:
+        return '/'
     else:
-        return b'/'.join(path)
+        return '/'.join(path)
 
 
 # jam 20060502 Sorted to 'l' because the final target is 'local_path_from_url'
 def _posix_local_path_from_url(url):
     """Convert a url like file:///path/to/foo into /path/to/foo"""
     url = split_segment_parameters_raw(url)[0]
-    file_localhost_prefix = b'file://localhost/'
+    file_localhost_prefix = 'file://localhost/'
     if url.startswith(file_localhost_prefix):
         path = url[len(file_localhost_prefix) - 1:]
-    elif not url.startswith(b'file:///'):
+    elif not url.startswith('file:///'):
         raise errors.InvalidURL(
             url, 'local urls must start with file:/// or file://localhost/')
     else:
-        path = url[len(b'file://'):]
+        path = url[len('file://'):]
     # We only strip off 2 slashes
     return unescape(path)
 
@@ -282,7 +265,7 @@
     """
     # importing directly from posixpath allows us to test this
     # on non-posix platforms
-    return b'file://' + escape(osutils._posix_abspath(path))
+    return 'file://' + escape(osutils._posix_abspath(path))
 
 
 def _win32_local_path_from_url(url):
@@ -350,8 +333,8 @@
     MIN_ABS_FILEURL_LENGTH = WIN32_MIN_ABS_FILEURL_LENGTH
 
 
-_url_scheme_re = re.compile(b'^(?P<scheme>[^:/]{2,}):(//)?(?P<path>.*)$')
-_url_hex_escapes_re = re.compile(b'(%[0-9a-fA-F]{2})')
+_url_scheme_re = re.compile('^(?P<scheme>[^:/]{2,}):(//)?(?P<path>.*)$')
+_url_hex_escapes_re = re.compile('(%[0-9a-fA-F]{2})')
 
 
 def _unescape_safe_chars(matchobj):
@@ -391,7 +374,7 @@
         return local_path_to_url(url)
     prefix = url[:path_start]
     path = url[path_start:]
-    if not isinstance(url, unicode):
+    if not isinstance(url, text_type):
         for c in url:
             if c not in _url_safe_characters:
                 raise errors.InvalidURL(url, 'URLs can only contain specific'
@@ -527,10 +510,10 @@
     #                should not be blindly adding slashes in the first place. 
     lurl = strip_trailing_slash(url)
     # Segments begin at first comma after last forward slash, if one exists
-    segment_start = lurl.find(b",", lurl.rfind(b"/")+1)
+    segment_start = lurl.find(",", lurl.rfind("/")+1)
     if segment_start == -1:
         return (url, [])
-    return (lurl[:segment_start], lurl[segment_start+1:].split(b","))
+    return (lurl[:segment_start], lurl[segment_start+1:].split(","))
 
 
 def split_segment_parameters(url):
@@ -621,10 +604,10 @@
         # format which does it differently.
         file:///c|/       => file:///c:/
     """
-    if not url.endswith(b'/'):
+    if not url.endswith('/'):
         # Nothing to do
         return url
-    if sys.platform == 'win32' and url.startswith(b'file://'):
+    if sys.platform == 'win32' and url.startswith('file://'):
         return _win32_strip_local_trailing_slash(url)
 
     scheme_loc, first_path_slash = _find_scheme_and_separator(url)
@@ -658,8 +641,10 @@
             url = url.encode("ascii")
         except UnicodeError as e:
             raise errors.InvalidURL(url, 'URL was not a plain ASCII url: %s' % (e,))
-
-    unquoted = unquote(url)
+    if PY3:
+        unquoted = urlparse.unquote_to_bytes(url)
+    else:
+        unquoted = unquote(url)
     try:
         unicode_path = unquoted.decode('utf-8')
     except UnicodeError as e:
@@ -859,9 +844,9 @@
 
         :param url: URL as bytestring
         """
-        if isinstance(url, unicode):
+        # GZ 2017-06-09: Actually validate ascii-ness
+        if not isinstance(url, str):
             raise errors.InvalidURL('should be ascii:\n%r' % url)
-        url = url.encode('utf-8')
         (scheme, netloc, path, params,
          query, fragment) = urlparse.urlparse(url, allow_fragments=False)
         user = password = host = port = None

=== modified file 'breezy/workingtree_4.py'
--- breezy/workingtree_4.py	2017-06-07 00:28:00 +0000
+++ breezy/workingtree_4.py	2017-06-10 01:57:00 +0000
@@ -130,18 +130,18 @@
         """See MutableTree._add."""
         state = self.current_dirstate()
         for f, file_id, kind in zip(files, ids, kinds):
-            f = f.strip('/')
+            f = f.strip(b'/')
             if self.path2id(f):
                 # special case tree root handling.
-                if f == '' and self.path2id(f) == ROOT_ID:
-                    state.set_path_id('', generate_ids.gen_file_id(f))
+                if f == b'' and self.path2id(f) == ROOT_ID:
+                    state.set_path_id(b'', generate_ids.gen_file_id(f))
                 continue
             if file_id is None:
                 file_id = generate_ids.gen_file_id(f)
             # deliberately add the file with no cached stat or sha1
             # - on the first access it will be gathered, and we can
             # always change this once tests are all passing.
-            state.add(f, file_id, kind, None, '')
+            state.add(f, file_id, kind, None, b'')
         self._make_dirty(reset_inventory=True)
 
     def _get_check_refs(self):
@@ -312,7 +312,7 @@
         state._read_dirblocks_if_needed()
         root_key, current_entry = self._get_entry(path='')
         current_id = root_key[2]
-        if not (current_entry[0][0] == 'd'): # directory
+        if not (current_entry[0][0] == b'd'): # directory
             raise AssertionError(current_entry)
         inv = Inventory(root_id=current_id)
         # Turn some things into local variables
@@ -332,7 +332,7 @@
                 continue
             for key, entry in block[1]:
                 minikind, link_or_sha1, size, executable, stat = entry[0]
-                if minikind in ('a', 'r'): # absent, relocated
+                if minikind in (b'a', b'r'): # absent, relocated
                     # a parent tree only entry
                     continue
                 name = key[1]
@@ -350,7 +350,7 @@
                     #inv_entry.text_sha1 = sha1
                 elif kind == 'directory':
                     # add this entry to the parent map.
-                    parent_ies[(dirname + '/' + name).strip('/')] = inv_entry
+                    parent_ies[(dirname + b'/' + name).strip(b'/')] = inv_entry
                 elif kind == 'tree-reference':
                     if not self._repo_supports_tree_reference:
                         raise errors.UnsupportedOperation(
@@ -408,7 +408,7 @@
                     raise
         link_or_sha1 = dirstate.update_entry(state, entry, file_abspath,
             stat_value=stat_value)
-        if entry[1][0][0] == 'f':
+        if entry[1][0][0] == b'f':
             if link_or_sha1 is None:
                 file_obj, statvalue = self.get_file_with_stat(file_id, path)
                 try:
@@ -509,7 +509,7 @@
         self._must_be_locked()
         result = set()
         for key, tree_details in self.current_dirstate()._iter_entries():
-            if tree_details[0][0] in ('a', 'r'): # relocated
+            if tree_details[0][0] in (b'a', b'r'): # relocated
                 continue
             result.add(key[2])
         return result
@@ -523,7 +523,7 @@
         """
         result = []
         for key, tree_details in self.current_dirstate()._iter_entries():
-            if tree_details[0][0] in ('a', 'r'): # absent, relocated
+            if tree_details[0][0] in (b'a', b'r'): # absent, relocated
                 # not relevant to the working tree
                 continue
             path = pathjoin(self.basedir, key[0].decode('utf8'), key[1].decode('utf8'))
@@ -537,7 +537,7 @@
             # return
             return
         for key, tree_details in self.current_dirstate()._iter_entries():
-            if tree_details[0][0] in ('a', 'r'): # absent, relocated
+            if tree_details[0][0] in (b'a', b'r'): # absent, relocated
                 # not relevant to the working tree
                 continue
             if not key[1]:
@@ -577,7 +577,7 @@
         if (self._repo_supports_tree_reference and kind == 'directory'):
             entry = self._get_entry(path=relpath)
             if entry[1] is not None:
-                if entry[1][0][0] == 't':
+                if entry[1][0][0] == b't':
                     kind = 'tree-reference'
         return kind
 
@@ -804,10 +804,10 @@
                          to_key=to_key,
                          to_path_utf8=to_rel_utf8)
 
-                if minikind == 'd':
+                if minikind == b'd':
                     def update_dirblock(from_dir, to_key, to_dir_utf8):
                         """Recursively update all entries in this dirblock."""
-                        if from_dir == '':
+                        if from_dir == b'':
                             raise AssertionError("renaming root not supported")
                         from_key = (from_dir, '')
                         from_block_idx, present = \
@@ -834,7 +834,7 @@
                             from_path_utf8 = osutils.pathjoin(entry[0][0], entry[0][1])
                             to_path_utf8 = osutils.pathjoin(to_dir_utf8, entry[0][1])
                             minikind = cur_details[0]
-                            if minikind in 'ar':
+                            if minikind in (b'a', b'r'):
                                 # Deleted children of a renamed directory
                                 # Do not need to be updated.
                                 # Children that have been renamed out of this
@@ -849,7 +849,7 @@
                                      to_block=to_block,
                                      to_key=to_key,
                                      to_path_utf8=to_path_utf8)
-                            if minikind == 'd':
+                            if minikind == b'd':
                                 # We need to move all the children of this
                                 # entry
                                 update_dirblock(from_path_utf8, to_key,
@@ -909,7 +909,7 @@
         # -- get the state object and prepare it.
         state = self.current_dirstate()
         if False and (state._dirblock_state == dirstate.DirState.NOT_IN_MEMORY
-            and '' not in paths):
+            and b'' not in paths):
             paths2ids = self._paths2ids_using_bisect
         else:
             paths2ids = self._paths2ids_in_memory
@@ -924,7 +924,7 @@
             """Return a list with all the entries that match path for all ids.
             """
             dirname, basename = os.path.split(path)
-            key = (dirname, basename, '')
+            key = (dirname, basename, b'')
             block_index, present = state._find_block_index_from_key(key)
             if not present:
                 # the block which should contain path is absent.
@@ -952,7 +952,7 @@
                 for entry in path_entries:
                     # for each tree.
                     for index in search_indexes:
-                        if entry[1][index][0] != 'a': # absent
+                        if entry[1][index][0] != b'a': # absent
                             found_versioned = True
                             # all good: found a versioned cell
                             break
@@ -981,10 +981,10 @@
             nothing. Otherwise add the id to found_ids.
             """
             for index in search_indexes:
-                if entry[1][index][0] == 'r': # relocated
+                if entry[1][index][0] == b'r': # relocated
                     if not osutils.is_inside_any(searched_paths, entry[1][index][1]):
                         search_paths.add(entry[1][index][1])
-                elif entry[1][index][0] != 'a': # absent
+                elif entry[1][index][0] != b'a': # absent
                     found_ids.add(entry[0][2])
         while search_paths:
             current_root = search_paths.pop()
@@ -997,7 +997,7 @@
                 continue
             for entry in root_entries:
                 _process_entry(entry)
-            initial_key = (current_root, '', '')
+            initial_key = (current_root, b'', b'')
             block_index, _ = state._find_block_index_from_key(initial_key)
             while (block_index < len(state._dirblocks) and
                 osutils.is_inside(current_root, state._dirblocks[block_index][0])):
@@ -1023,7 +1023,7 @@
 
         for dir_name_id, trees_info in viewitems(found):
             for index in search_indexes:
-                if trees_info[index][0] not in ('r', 'a'):
+                if trees_info[index][0] not in (b'r', b'a'):
                     found_ids.add(dir_name_id[2])
         return found_ids
 
@@ -1157,7 +1157,7 @@
     def _set_root_id(self, file_id):
         """See WorkingTree.set_root_id."""
         state = self.current_dirstate()
-        state.set_path_id('', file_id)
+        state.set_path_id(b'', file_id)
         if state._dirblock_state == dirstate.DirState.IN_MEMORY_MODIFIED:
             self._make_dirty(reset_inventory=True)
 
@@ -1666,7 +1666,7 @@
 
     def _init_custom_control_files(self, wt):
         """Subclasses with custom control files should override this method."""
-        wt._transport.put_bytes('views', '', mode=wt.bzrdir._get_file_mode())
+        wt._transport.put_bytes('views', b'', mode=wt.bzrdir._get_file_mode())
 
     def supports_content_filtering(self):
         return True
@@ -1794,7 +1794,7 @@
         # for the tree index use.
         root_key, current_entry = self._dirstate._get_entry(parent_index, path_utf8='')
         current_id = root_key[2]
-        if current_entry[parent_index][0] != 'd':
+        if current_entry[parent_index][0] != b'd':
             raise AssertionError()
         inv = Inventory(root_id=current_id, revision_id=self._revision_id)
         inv.root.revision = current_entry[parent_index][4]
@@ -1815,7 +1815,7 @@
                 continue
             for key, entry in block[1]:
                 minikind, fingerprint, size, executable, revid = entry[parent_index]
-                if minikind in ('a', 'r'): # absent, relocated
+                if minikind in (b'a', b'r'): # absent, relocated
                     # not this tree
                     continue
                 name = key[1]
@@ -1830,7 +1830,7 @@
                     inv_entry.text_size = size
                     inv_entry.text_sha1 = fingerprint
                 elif kind == 'directory':
-                    parent_ies[(dirname + '/' + name).strip('/')] = inv_entry
+                    parent_ies[(dirname + b'/' + name).strip(b'/')] = inv_entry
                 elif kind == 'symlink':
                     inv_entry.symlink_target = utf8_decode(fingerprint)[0]
                 elif kind == 'tree-reference':
@@ -1870,7 +1870,7 @@
         entry = self._get_entry(file_id=file_id, path=path)
         parent_index = self._get_parent_index()
         parent_details = entry[1][parent_index]
-        if parent_details[0] == 'f':
+        if parent_details[0] == b'f':
             return parent_details[1]
         return None
 
@@ -1922,7 +1922,7 @@
     def get_symlink_target(self, file_id, path=None):
         entry = self._get_entry(file_id=file_id)
         parent_index = self._get_parent_index()
-        if entry[1][parent_index][0] != 'l':
+        if entry[1][parent_index][0] != b'l':
             return None
         else:
             target = entry[1][parent_index][1]
@@ -2188,7 +2188,7 @@
                 specific_files_utf8.add(path.encode('utf8'))
             specific_files = specific_files_utf8
         else:
-            specific_files = {''}
+            specific_files = {b''}
         # -- specific_files is now a utf8 path set --
 
         # -- get the state object and prepare it.
@@ -2208,7 +2208,7 @@
                 for entry in path_entries:
                     # for each tree.
                     for index in indices:
-                        if entry[1][index][0] != 'a': # absent
+                        if entry[1][index][0] != b'a': # absent
                             found_versioned = True
                             # all good: found a versioned cell
                             break
@@ -2334,7 +2334,7 @@
 
     def init_custom_control_files(self, tree):
         """Initialize custom control files."""
-        tree._transport.put_bytes('views', '',
+        tree._transport.put_bytes('views', b'',
             mode=tree.bzrdir._get_file_mode())
 
     def update_format(self, tree):

